# basicModules
## Release history:
## `--- V1.0.4 ---`

`- Added StackOverFlow Functions -`

`- Added Ip Functions -`

`- Removed Roblox Functions due to it being broken -`

`- Added Integer Functions -`

`- Added Sudo Kill App -`

`- Added String Functions -`

`- Added Package Functions -`

`- Made all Functions to Scripts folder -`

## `--- V1.0.3 ---`

`- Added Roblox Functions -`

`- Added Shell Functions -`

`- Removed Emails due to insecurity -`

## `--- V1.0.2 ---`

`- Added Web Functions -`

`- Fixed issues with Emails -`
## `--- V1.0.1 ---`

`- V1.0.1 was recalled. -`